@@ -1,20 +1,29 @@
+"""
+.. code-block:: python
+
+    from aioauth.fastapi import utils
+
+Core utils for integration with FastAPI
+
+----
+"""
+
 import json
 
 from fastapi import Request, Response
 
-from aioauth.types import RequestMethod
-from aioauth.requests import (
-    Query,
-    Post,
-    Request as OAuth2Request,
-)
-from aioauth.responses import Response as OAuth2Response
 from aioauth.collections import HTTPHeaderDict
 from aioauth.config import Settings
+from aioauth.requests import Post, Query
+from aioauth.requests import Request as OAuth2Request
+from aioauth.responses import Response as OAuth2Response
+from aioauth.types import RequestMethod
 
 
-async def to_oauth2_request(request: Request, settings: Settings) -> OAuth2Request:
-    """Converts fastapi Request instance to OAuth2Request instance"""
+async def to_oauth2_request(
+    request: Request, settings: Settings = Settings()
+) -> OAuth2Request:
+    """Converts :py:class:`fastapi.Request` instance to :py:class:`aioauth.requests.Request` instance"""
     form = await request.form()
 
     post = dict(form)
@@ -40,7 +49,7 @@ async def to_oauth2_request(request: Request, settings: Settings) -> OAuth2Reque
 
 
 async def to_fastapi_response(oauth2_response: OAuth2Response) -> Response:
-    """Converts OAuth2Response instance to fastapi Response instance"""
+    """Converts :py:class:`aioauth.responses.Response` instance to :py:class:`fastapi.Response` instance"""
     response_content = oauth2_response.content
     headers = dict(oauth2_response.headers)
     status_code = oauth2_response.status_code
