@@ -4,10 +4,11 @@
     from aioauth import responses
 
 Response objects used throughout the project.
----------------------------------------------
+
+----
 """
 
-from .storage import BaseStorage
+from .utils import generate_token
 from .errors import (
     InvalidClientError,
     InvalidRequestError,
@@ -22,6 +23,7 @@ from .responses import (
     NoneResponse,
     TokenResponse,
 )
+from .storage import BaseStorage
 from .types import CodeChallengeMethod
 
 
@@ -90,7 +92,11 @@ class ResponseTypeToken(ResponseTypeBase):
         client = await super().validate_request(request)
 
         token = await self.storage.create_token(
-            request, client.client_id, request.query.scope
+            request,
+            client.client_id,
+            request.query.scope,
+            generate_token(42),
+            generate_token(48),
         )
         return TokenResponse(
             expires_in=token.expires_in,
@@ -118,6 +124,7 @@ class ResponseTypeAuthorizationCode(ResponseTypeBase):
             request.query.redirect_uri,
             request.query.code_challenge_method,
             request.query.code_challenge,
+            generate_token(42),
         )
         return AuthorizationCodeResponse(
             code=authorization_code.code,
