@@ -13,13 +13,14 @@ Warning:
     ``aiohttp`` to create a fully functional OAuth 2.0 server.
     Check out the *Examples* portion of the documentation to understand
     how it can be leveraged in your own project.
+
 ----
 """
 
 from http import HTTPStatus
 from typing import Dict, List, Optional, Union
 
-from .storage import BaseStorage
+from .collections import HTTPHeaderDict
 from .constances import default_headers
 from .errors import (
     InsecureTransportError,
@@ -47,7 +48,7 @@ from .responses import (
     TokenActiveIntrospectionResponse,
     TokenInactiveIntrospectionResponse,
 )
-from .collections import HTTPHeaderDict
+from .storage import BaseStorage
 from .types import GrantType, RequestMethod, ResponseMode, ResponseType, TokenType
 from .utils import (
     build_uri,
@@ -115,7 +116,9 @@ class AuthorizationServer:
             Below is an example utilizing FastAPI as the server framework.
         .. code-block:: python
 
-            @app.get("/introspect")
+            from aioauth.fastapi.utils import to_oauth2_request, to_fastapi_response
+
+            @app.get("/token/introspect")
             async def introspect(request: fastapi.Request) -> fastapi.Response:
                 # Converts a fastapi.Request to an aioauth.Request.
                 oauth2_request: aioauth.Request = await to_oauth2_request(request)
@@ -140,8 +143,8 @@ class AuthorizationServer:
         access_token = None
         refresh_token = request.post.token
 
-        if request.post.token_type in token_types:
-            token_type = request.post.token_type  # type: ignore
+        if request.post.token_type_hint in token_types:
+            token_type = request.post.token_type_hint  # type: ignore
 
         if token_type == TokenType.ACCESS:
             access_token = request.post.token
@@ -190,6 +193,8 @@ class AuthorizationServer:
             Below is an example utilizing FastAPI as the server framework.
         .. code-block:: python
 
+            from aioauth.fastapi.utils import to_oauth2_request, to_fastapi_response
+
             @app.post("/token")
             async def token(request: fastapi.Request) -> fastapi.Response:
                 # Converts a fastapi.Request to an aioauth.Request.
@@ -246,6 +251,8 @@ class AuthorizationServer:
             Below is an example utilizing FastAPI as the server framework.
         .. code-block:: python
 
+            from aioauth.fastapi.utils import to_oauth2_request, to_fastapi_response
+
             @app.post("/authorize")
             async def authorize(request: fastapi.Request) -> fastapi.Response:
                 # Converts a fastapi.Request to an aioauth.Request.
